==> haskell-non-negative-0.1.2-315-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-DtFMq09cLg6Jz45DiI8kCF
key:                  non-negative-0.1.2-DtFMq09cLg6Jz45DiI8kCF
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  71b8836e30244c14021eb6e8ff58acaa
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-DtFMq09cLg6Jz45DiI8kCF
depends:
    QuickCheck-2.15.0.1-CJDLs8WzPRbDbbjHGUhpIu base-4.17.2.1
    utility-ht-0.0.17.2-EdtnUt8ynzSBuI4KEWKvqW

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.2-316-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-KEutPZCg33VI12GoOmPPzx
key:                  non-negative-0.1.2-KEutPZCg33VI12GoOmPPzx
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  c583fbdd59818895b866e528da232ec0
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-KEutPZCg33VI12GoOmPPzx
depends:
    QuickCheck-2.15.0.1-93Z9357UkgtKg8lpP8YyKm base-4.17.2.1
    utility-ht-0.0.17.2-B0EiZkVvuw79fbKTKgMyrN

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
